cgexplore.terms.CosineAngle
===========================

.. currentmodule:: cgexplore.terms

.. autoclass:: CosineAngle
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CosineAngle.atom_names
      ~CosineAngle.atom_ids
      ~CosineAngle.n
      ~CosineAngle.b
      ~CosineAngle.angle_k
      ~CosineAngle.atoms
      ~CosineAngle.force
   
   